/**
   \file    vector.cc
   \brief   numerical vector class
   \author  Clemens Pechstein
   \date    November 2009
*/
#include "vector.hh"


void Vector :: setToZero ()
{
  for (int i=0; i<(int)vec_.size(); ++i) vec_[i] = 0.;
}


void Vector :: print (ostream& os) const
{
  os << '[';
  if (vec_.size () > 0) os << vec_[0];
  for (size_t i=1; i<vec_.size(); ++i) os << ", " << vec_[i];
  os << ']';
}

Vector& Vector :: operator+= (const Vector& v)
{
  assert (v.size() == size());
  vec_ += v.vec_;
  return *this;
}

Vector& Vector :: operator-= (const Vector& v)
{
  assert (v.size() == size());
  vec_ -= v.vec_;
  return *this;
}

Vector& Vector :: operator*= (double factor)
{
  vec_ *= factor;
  return *this;
}

double Vector :: l2norm () const
{
  double sum = 0;
  for (int i=0; i<size(); ++i)
    {
	sum += vec_[i]*vec_[i];
    }
  return sqrt(sum);
}

double inner_product (const Vector& v, const Vector& w)
{
  assert (v.size () > 0 && v.size() == w.size());
  double sum = 0;
  for (int i=0; i<v.size(); ++i)
    {
      sum += v[i] * w[i];
    }
  return sum;
}

// EOF
